/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.api.request;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;

/**
 * 请求实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@ApiModel(value = "新增寄售订单实体对象", description = "请求实体类")
public class OrderConsignSaveRequest implements Serializable {

	private static final long serialVersionUID = 1L;

	@NotNull
	@ApiModelProperty(value = "用户ID")
	private Long userId;

	@NotNull
	@ApiModelProperty(value = "寄售商品ID")
	private Long consignId;

	@NotBlank(message = "请输入手机号")
	@ApiModelProperty(value = "手机号")
	private String telPhone;

	@NotNull
	@ApiModelProperty(value = "支付价")
	private Double payFee;

	@Min(value = 1)
	@Max(value = 2)
	@ApiModelProperty(value = "寄售方式，1提货，2寄售")
	private Integer consignType;

	@Min(value = 1)
	@Max(value = 3)
	@ApiModelProperty(value = "寄售天数")
	private Integer consignDays;

	@NotBlank(message = "请输入收货地址")
	@ApiModelProperty(value = "收货地址")
	private String userAddress;

	@NotBlank(message = "请输入收货人")
	@ApiModelProperty(value = "收货人")
	private String receivingName;

	@NotNull
	@ApiModelProperty(value = "商品ID")
	private Long goodsId;

	@ApiModelProperty(value = "商品规格ID:格式：xxx,xxx,xxx")
	private String goodsSpecIds;


}
