/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * 订单预授权表实体类
 *
 * @author BladeX
 * @since 2022-03-27
 */
@Data
@TableName("t_order_grant")
@ApiModel(value = "OrderGrant对象", description = "订单预授权表")
public class OrderGrant implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 主键ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "主键ID")
	private Long id;

	/**
	 * 订单号
	 */
	@ApiModelProperty(value = "订单号")
	private String orderNo;

	/**
	 * 业务NO
	 */
	@ApiModelProperty(value = "业务类型")
	private String authNo;

	/**
	 * 批次ID
	 */
	@ApiModelProperty(value = "批次ID")
	private Long batNo;

	/**
	 * 用户ID
	 */
	@ApiModelProperty(value = "用户ID")
	private Long userId;

	/**
	 * 价格
	 */
	@ApiModelProperty(value = "价格")
	private Double price;

	/**
	 * 数量
	 */
	@ApiModelProperty(value = "数量")
	private Integer num;

	/**
	 * 剩余数量
	 */
	@ApiModelProperty(value = "剩余数量")
	private Integer nowNum;

	/**
	 * 状态：0未授权，1:已授权,2:解冻
	 */
	@ApiModelProperty(value = "状态：0未授权，1:已授权,2:解冻")
	private Integer status;

	/**
	 * 数据日期
	 */
	@ApiModelProperty(value = "数据日期")
	private String dataDate;

	/**
	 * 冻结时间
	 */
	@ApiModelProperty(value = "冻结时间")
	private Date freezeTime;
	/**
	 * 创建时间
	 */
	@ApiModelProperty(value = "创建时间")
	private Date createTime;
	/**
	 * 解冻时间
	 */
	@ApiModelProperty(value = "解冻时间")
	private Date unfreezeTime;


}
