/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.service;

import org.springblade.modules.api.request.OrderCommonSaveRequest;
import org.springblade.modules.api.request.OrderConsignRandomRequest;
import org.springblade.modules.api.request.OrderConsignSaveRequest;
import org.springblade.modules.api.response.ConsignResponse;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.api.request.OrderTakeRequest;
import org.springblade.modules.finance.vo.OrderVO;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.core.metadata.IPage;

/**
 * 订单表 服务类
 *
 * @author BladeX
 * @since 2022-02-13
 */
public interface IOrderService extends IService<Order> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param order
	 * @return
	 */
	IPage<OrderVO> selectOrderPage(IPage<OrderVO> page, OrderVO order);


	/**
	 * 生成普通订单
	 * @param request 请求参数
	 * @param tenantId 租户号
	 * @return 订单号
	 */
	String commonOrderInsert(OrderCommonSaveRequest request, String tenantId);

	/**
	 * 普通订单支付成功
	 * 1.订单表
	 * 	 订单状态pay_flag： 待付款 -> 待发货
	 * 2.如果是抢购而且是寄售类型consignType为寄售则添加寄售数据
	 * @param outTradeNo 订单号
	 * @return boolean
	 */
	boolean payCommonSuccess(String outTradeNo, String payCode);

	/**
	 * 订单完成
	 * 1.订单表
	 * 	用户确认收货、或者商家确认收货
	 * 2.寄售订单表
	 *
	 * @param orderId 订单ID
	 * @return boolean
	 */
	boolean orderEnd(Long orderId, Long userId);

	/**
	 * 生成寄售订单
	 * 1.寄售商品表
	 * 	寄售状态consign_state： 寄售中 -> 已寄售/已售出
	 * 2.订单表
	 * 	订单状态pay_flag：为待付款
	 * 3.寄售订单表
	 * 	抢购状态consign_flag: 为待付款
	 * @param request 请求参数
	 * @param tenantId 租户号
	 * @return 订单号
	 */
	String consignOrderInsert(OrderConsignSaveRequest request, String tenantId);

	/**
	 * 提货
	 * 订单状态变为待收货
	 * @param request 用户ID
	 * @return
	 */
	boolean consignSelfTake(OrderTakeRequest request);


	/**
	 * 寄售抢购
	 * @param request 请求参数
	 * @param tenantId 租户号
	 * @return Response
	 */
	ConsignResponse consignOrderInsert(OrderConsignRandomRequest request, String tenantId);
}
