/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.platform.entity.UserCardInfo;
import org.springblade.modules.platform.service.IUserCardInfoService;
import org.springblade.modules.platform.vo.UserCardInfoVO;
import org.springblade.modules.platform.wrapper.UserAppWrapper;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.vo.UserAppVO;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 用户列表 控制器
 *
 * @author BladeX
 * @since 2022-03-28
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/userApp")
@Api(value = "用户表", tags = "用户表接口")
public class UserAppController extends BladeController {

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入userApp")
	public R<UserApp> detail(UserApp userApp) {
		UserApp detail = userApp.selectOne(Condition.getQueryWrapper(userApp));
		return R.data(detail);
	}

	/**
	 * 分页 app用户表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入userApp")
	public R<IPage<UserAppVO>> list(UserApp userApp, Query query) {
		IPage<UserApp> pages = userApp.selectPage(Condition.getPage(query), Condition.getQueryWrapper(userApp));
		return R.data(UserAppWrapper.build().pageVO(pages));
	}


	/**
	 * 新增 app用户表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入userApp")
	public R save(@Valid @RequestBody UserApp userApp) {
		return R.status(userApp.insert());
	}

	/**
	 * 修改 app用户表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入userApp")
	public R update(@Valid @RequestBody UserApp userApp) {
		return R.status(userApp.updateById());
	}

	/**
	 * 新增或修改 app用户表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入userApp")
	public R submit(@Valid @RequestBody UserApp userApp) {
		return R.status(userApp.insertOrUpdate());
	}


	/**
	 * 删除 app用户表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		UserApp userApp = new UserApp();
		List<Long> list = Func.toLongList(ids);
		list.forEach(userApp::deleteById);
		return R.status(true);
	}


}
