/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * 用户积分表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_user_scores")
@ApiModel(value = "UserScores对象", description = "用户积分表")
public class UserScores implements Serializable {

	private static final long serialVersionUID = 1L;

	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "主键Id")
	private Long id;
	/**
	 * 用户ID
	 */
	@ApiModelProperty(value = "用户ID")
	private Long userId;
	/**
	 * 数据类型: 1信用积分，2用户积分
	 */
	@ApiModelProperty(value = "数据类型: 1信用积分，2用户积分")
	private Boolean dataType;
	/**
	 * 积分数
	 */
	@ApiModelProperty(value = "积分数")
	private BigDecimal score;
	/**
	 * 来源:1订单 2评价 3订单取消返还 4拒收返还
	 */
	@ApiModelProperty(value = "来源:1订单 2评价 3订单取消返还 4拒收返还")
	private String dataSrc;
	/**
	 * 来源记录ID
	 */
	@ApiModelProperty(value = "来源记录ID")
	private Long dataId;
	/**
	 * 描述
	 */
	@ApiModelProperty(value = "描述")
	private String dataRemarks;
	/**
	 * 积分类型：1:收入 2：支出
	 */
	@ApiModelProperty(value = "积分类型：1:收入 2：支出")
	private Boolean scoreType;
	/**
	 * 创建时间
	 */
	@ApiModelProperty(value = "创建时间")
	private LocalDateTime createTime;


}
