/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.shopping.entity.Category;
import org.springblade.modules.shopping.service.ICategoryService;
import org.springblade.modules.shopping.wrapper.SpecCatsWrapper;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.shopping.entity.SpecCats;
import org.springblade.modules.shopping.vo.SpecCatsVO;
import org.springblade.modules.shopping.service.ISpecCatsService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 规格分类表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/speccats")
@Api(value = "规格分类表", tags = "规格分类表接口")
public class SpecCatsController extends BladeController {

	private final ISpecCatsService specCatsService;
	private final ICategoryService categoryService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入specCats")
	public R<SpecCats> detail(SpecCats specCats) {
		SpecCats detail = specCatsService.getOne(Condition.getQueryWrapper(specCats));
		return R.data(detail);
	}

	/**
	 * 分页 规格分类表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入specCats")
	public R<IPage<SpecCatsVO>> list(SpecCats specCats, Query query) {
		IPage<SpecCats> pages = specCatsService.page(Condition.getPage(query), Condition.getQueryWrapper(specCats));
		return R.data(SpecCatsWrapper.build().pageVO(pages));
	}

	/**
	 * 自定义分页 规格分类表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入specCats")
	public R<IPage<SpecCatsVO>> page(SpecCatsVO specCats, Query query) {
		IPage<SpecCatsVO> pages = specCatsService.selectSpecCatsPage(Condition.getPage(query), specCats);
		return R.data(pages);
	}

	/**
	 * 新增 规格分类表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入specCats")
	public R save(@Valid @RequestBody SpecCats specCats) {
		return R.status(specCatsService.save(specCats));
	}

	/**
	 * 修改 规格分类表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入specCats")
	public R update(@Valid @RequestBody SpecCats specCats) {
		return R.status(specCatsService.updateById(specCats));
	}

	/**
	 * 新增或修改 规格分类表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入specCats")
	public R submit(@Valid @RequestBody SpecCats specCats) {
		if(specCats.getCatId() != null){
			Category category = categoryService.getById(specCats.getCatId());
			if (category != null){
				specCats.setCatName(category.getName());
			}
		}
		return R.status(specCatsService.saveOrUpdate(specCats));
	}


	/**
	 * 删除 规格分类表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(specCatsService.removeByIds(Func.toLongList(ids)));
	}


}
