/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;

/**
 * 分类表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_category")
@ApiModel(value = "Category对象", description = "分类表")
public class Category implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 分类ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "分类ID")
	private Long id;
	/**
	 * 分类父ID
	 */
	@ApiModelProperty(value = "分类父ID")
	private Long parentId;
	/**
	 * 分类值
	 */
	@ApiModelProperty(value = "分类值")
	private String value;
	/**
	 * 分类名称
	 */
	@ApiModelProperty(value = "分类名称")
	private String name;
	/**
	 * SEO标题
	 */
	@ApiModelProperty(value = "SEO标题")
	private String seoTitle;
	/**
	 * SEO关键字
	 */
	@ApiModelProperty(value = "SEO关键字")
	private String seoKeyword;
	/**
	 * SEO描述
	 */
	@ApiModelProperty(value = "SEO描述")
	private String seoDesc;
	/**
	 * 排序
	 */
	@ApiModelProperty(value = "排序")
	private Integer sort;
	/**
	 * 是否已删除
	 */
	@TableLogic
	@ApiModelProperty(value = "是否已删除")
	private Integer isDeleted;


}
