/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.wrapper;

import org.springblade.common.cache.DictCache;
import org.springblade.common.enums.DictEnum;
import org.springblade.core.mp.support.BaseEntityWrapper;
import org.springblade.core.tool.utils.BeanUtil;
import org.springblade.core.tool.utils.SpringUtil;
import org.springblade.modules.shopping.entity.Goods;
import org.springblade.modules.shopping.entity.GoodsSpecs;
import org.springblade.modules.shopping.service.IGoodsService;
import org.springblade.modules.shopping.vo.GoodsSpecsVO;

import java.util.Objects;

/**
 * 包装类,返回视图层所需的字段
 *
 * @author Chill
 */
public class GoodsSpecsWrapper extends BaseEntityWrapper<GoodsSpecs, GoodsSpecsVO> {

	public static GoodsSpecsWrapper build() {
		return new GoodsSpecsWrapper();
	}

	public static IGoodsService goodsService;

	static {
		goodsService = SpringUtil.getBean(IGoodsService.class);
	}

	@Override
	public GoodsSpecsVO entityVO(GoodsSpecs entity) {
		GoodsSpecsVO vo = Objects.requireNonNull(BeanUtil.copy(entity, GoodsSpecsVO.class));
		vo.setIsDefaultDisplayName(DictCache.getValue(DictEnum.YES_NO, entity.getIsDefault()));
		Goods goods = goodsService.getById(entity.getGoodsId());
		if (goods != null){
			vo.setGoodsName(goods.getGoodsName());
			vo.setProductNo(goods.getProductNo());
		}
		return vo;
	}

}
